if not Watcher then return end

local L = LibStub("AceLocale-3.0"):GetLocale("Watcher")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");
local C = Watcher.constants -- Defined in Watcher LUA no locale needed.

Watcher.fonteffects = {
	["none"] = L["None"],
	["OUTLINE"] = L["OUTLINE"],
	["THICKOUTLINE"] = L["THICKOUTLINE"],
	["MONOCHROME"] = L["MONOCHROME"],
}

function Watcher:GetOptions()
	local options = { 
		name = "Watcher",
		handler = Watcher,
		type='group',
		childGroups ='tree',
		args = {
			Display = {
				name = L["Display Settings"],
				type = 'group',
				order = 1, 
				args = {
					combat = {
						type = 'toggle',
						name = L["Show only in combat"],
						get = "GetShowCombat",
						set = "ActivateShowCombat",
						order = 1,
					},
					party = {
						type = 'toggle',
						name = L["Show only in party"],
						get = "GetShowParty",
						set = "ActivateShowParty",
						order = 2,
					},
					raid = {
						type = 'toggle',
						name = L["Show only in raid"],
						get = "GetShowRaid",
						set = "ActivateShowRaid",
						order = 3,
					},
					text = {
						type = 'toggle',
						name = L["Display CD text"],
						get = "priorityTextQuery",
						set = "ActivatePriorityText",
						order = 22,
					},
					scale = {
						type = 'range',
						name = L["Bar Scale"],
						desc = L["help_scale"],
						min = 0.25,
						max = 3.00,
						step = 0.05,
						get = "GetScale",
						set = "SetScale",
						order = 32,
					},
					iconsize = {
						type = 'range',
						name = L["Icon Size"],
						desc = L["help_size"],
						min = 10,
						max = 50,
						step = 5,
						get = "GetSize",
						set = "SetSize",
						order = 33,
					},
					alpha = {
						type = 'range',
						name = L["Alpha"],
						desc = L["help_alpha"],
						min = 0,
						max = 1,
						step = 0.05,
						get = "GetAlpha",
						set = "SetAlpha",
						order = 34,
					},
					balpha = {
						type = 'range',
						name = L["Background Alpha"],
						desc = L["help_balpha"],
						min = 0,
						max = 1,
						step = 0.05,
						get = "GetBAlpha",
						set = "SetBAlpha",
						order = 35,
					},
					maxtime = {
						type = 'range',
						name = L["MaxTime"],
						desc = L["help_maxtime"],
						min = 5,
						max = 12,
						step = 1,
						get = "Getmaxtime",
						set = "Setmaxtime",
						order = 37,
					},
					axis =  {
						type = 'toggle',
						name = L["Show axis"],
						desc = L["help_axis"],
						get = "Getaxis",
						set = "Activateaxis",
						order = 35,
					},
					gcd = {
						type = 'toggle',
						name = L["Show GCD"],
						desc = L["help_gcd"],
						get = "GetGCD",
						set = "ActivateGCD",
						order = 38,
					},
					direction = {
						type = 'select',
						name = L["Direction"],
						desc = L["help_Dir"],
						get = "GetDirection",
						set = "SetDirection",
						values = self.dir,
						order = 39,
					},
				},
			},
			prioritytable1 = {
				name = L["Priority Table 1"],
				order = 2,
				type = 'group',
				args = {
					priority1 = {
						type = 'select',
						name = L["First Priority"],
						get = "GetFirstPriority",
						set = "SetFirstPriority",
						values = self.priorityTable.name,
						order = 26,
					},
					priority2 = {
						type = 'select',
						name = L["Second Priority"],
						get = "GetSecondPriority",
						set = "SetSecondPriority",
						values = self.priorityTable.name,
						order = 28,
					},
					priority3 = {
						type = 'select',
						name = L["Third Priority"],
						get = "GetThirdPriority",
						set = "SetThirdPriority",
						values = self.priorityTable.name,
						order = 30,
					},
					priority4 = {
						type = 'select',
						name = L["Fourth Priority"],
						get = "GetFourthPriority",
						set = "SetFourthPriority",
						values = self.priorityTable.name,
						order = 32,
					},
					priority5 = {
						type = 'select',
						name = L["Fifth Priority"],
						get = "GetFifthPriority",
						set = "SetFifthPriority",
						values = self.priorityTable.name,
						order = 34,
					},
					priority6 = {
						type = 'select',
						name = L["Sixth Priority"],
						get = "GetSixthPriority",
						set = "SetSixthPriority",
						values = self.priorityTable.name,
						order = 36,
					},
					priority7 = {
						type = 'select',
						name = L["Seventh Priority"],
						get = "GetSeventhPriority",
						set = "SetSeventhPriority",
						values = self.priorityTable.name,
						order = 38,
					},
					priority8 = {
						type = 'select',
						name = L["Eighth Priority"],
						get = "GetEighthPriority",
						set = "SetEighthPriority",
						values = self.priorityTable.name,
						order = 40,
					},
					showraidboss1 = {
						type = 'toggle',
						name = L["showraidboss1"],
						get = "GetFirstshowraidboss",
						set = "SetFirstshowraidboss",
						order = 27,
					},
					showraidboss2 = {
						type = 'toggle',
						name = L["showraidboss2"],
						get = "GetSecondshowraidboss",
						set = "SetSecondshowraidboss",
						order = 29,
					},
					showraidboss3 = {
						type = 'toggle',
						name = L["showraidboss3"],
						get = "GetThirdshowraidboss",
						set = "SetThirdshowraidboss",
						order = 31,
					},
					showraidboss4 = {
						type = 'toggle',
						name = L["showraidboss4"],
						get = "GetFourthshowraidboss",
						set = "SetFourthshowraidboss",
						order = 33,
					},
					showraidboss5 = {
						type = 'toggle',
						name = L["showraidboss5"],
						get = "GetFifthshowraidboss",
						set = "SetFifthshowraidboss",
						order = 35,
					},
					showraidboss6 = {
						type = 'toggle',
						name = L["showraidboss6"],
						get = "GetSixthshowraidboss",
						set = "SetSixthshowraidboss",
						order = 37,
					},
					showraidboss7 = {
						type = 'toggle',
						name = L["showraidboss7"],
						get = "GetSeventhshowraidboss",
						set = "SetSeventhshowraidboss",
						order = 39,
					},
					showraidboss8 = {
						type = 'toggle',
						name = L["showraidboss8"],
						get = "GetEighthshowraidboss",
						set = "SetEighthshowraidboss",
						order = 41,
					},
				},
			},
			prioritytable2 = {
				name = L["Priority Table 2"],
				order = 3,
				type = 'group',
				args = {
					priority1 = {
						type = 'select',
						name = L["First Priority"],
						get = "GetFirstPriority2",
						set = "SetFirstPriority2",
						values = self.priorityTable.name,
						order = 26,
					},
					priority2 = {
						type = 'select',
						name = L["Second Priority"],
						get = "GetSecondPriority2",
						set = "SetSecondPriority2",
						values = self.priorityTable.name,
						order = 28,
					},
					priority3 = {
						type = 'select',
						name = L["Third Priority"],
						get = "GetThirdPriority2",
						set = "SetThirdPriority2",
						values = self.priorityTable.name,
						order = 30,
					},
					priority4 = {
						type = 'select',
						name = L["Fourth Priority"],
						get = "GetFourthPriority2",
						set = "SetFourthPriority2",
						values = self.priorityTable.name,
						order = 32,
					},
					priority5 = {
						type = 'select',
						name = L["Fifth Priority"],
						get = "GetFifthPriority2",
						set = "SetFifthPriority2",
						values = self.priorityTable.name,
						order = 34,
					},
					priority6 = {
						type = 'select',
						name = L["Sixth Priority"],
						get = "GetSixthPriority2",
						set = "SetSixthPriority2",
						values = self.priorityTable.name,
						order = 36,
					},
					priority7 = {
						type = 'select',
						name = L["Seventh Priority"],
						get = "GetSeventhPriority2",
						set = "SetSeventhPriority2",
						values = self.priorityTable.name,
						order = 38,
					},
					priority8 = {
						type = 'select',
						name = L["Eighth Priority"],
						get = "GetEighthPriority2",
						set = "SetEighthPriority2",
						values = self.priorityTable.name,
						order = 40,
					},
					showraidboss1 = {
						type = 'toggle',
						name = L["showraidboss1"],
						get = "GetFirstshowraidboss2",
						set = "SetFirstshowraidboss2",
						order = 27,
					},
					showraidboss2 = {
						type = 'toggle',
						name = L["showraidboss2"],
						get = "GetSecondshowraidboss2",
						set = "SetSecondshowraidboss2",
						order = 29,
					},
					showraidboss3 = {
						type = 'toggle',
						name = L["showraidboss3"],
						get = "GetThirdshowraidboss2",
						set = "SetThirdshowraidboss2",
						order = 31,
					},
					showraidboss4 = {
						type = 'toggle',
						name = L["showraidboss4"],
						get = "GetFourthshowraidboss2",
						set = "SetFourthshowraidboss2",
						order = 33,
					},
					showraidboss5 = {
						type = 'toggle',
						name = L["showraidboss5"],
						get = "GetFifthshowraidboss2",
						set = "SetFifthshowraidboss2",
						order = 35,
					},
					showraidboss6 = {
						type = 'toggle',
						name = L["showraidboss6"],
						get = "GetSixthshowraidboss2",
						set = "SetSixthshowraidboss2",
						order = 37,
					},
					showraidboss7 = {
						type = 'toggle',
						name = L["showraidboss7"],
						get = "GetSeventhshowraidboss2",
						set = "SetSeventhshowraidboss2",
						order = 39,
					},
					showraidboss8 = {
						type = 'toggle',
						name = L["showraidboss8"],
						get = "GetEighthshowraidboss2",
						set = "SetEighthshowraidboss2",
						order = 41,
					},
				},
			},
			enable = {
				type = 'toggle',
				name = L["Enable"],
				desc = L["help_enable"],
				get = "EnableQuery",
				set = "ActivateEnable",
				order = 10,
			},			moveframes = {
				type = 'toggle',
				name = L["Move Frames"],
				desc = L["help_display"],
				get = "BarShowQuery",
				set = "ShowHideFrame",
				order = 10,
			},
			config = {
				type = 'execute',
				name = L["Configure Options"],
				desc = L["help_config"],
				func = "OpenConfig",
				order = 13,
			},
			version = {
				type = 'execute',
				name = L["Version"],
				desc = L["help_version"],
				func = "DisplayVersion",
				order = 15,
			},
			help = {
				type = 'description',
				name = L["help"],
				guiHidden = true,
				order = 16,
			},
			resetpriority = {
				type = 'execute',
				name = L["Reset"],
				desc = L["help_reset_priority"],
				func = "ResetPriority",
				order = 36,
					},
		},
	}
	return options
end

function Watcher:ActivateGCD()
	self.db.char.showgcd = not self.db.char.showgcd
	self:CreatePriorityFrame()
	if (self.db.char.showgcd) then
		self:Print(L["config_GCD_on"])
	else
		self:Print(L["config_GCD_off"])
	end
end

function Watcher:ActivateEnable()
	self.db.char.enable = not self.db.char.enable
	--self:CreatePriorityFrame()
	if (self.db.char.enable) then
		self:Print(L["config_enable_on"])
		self.PriorityFrame:Show()
		self:CreatePriorityFrame()
	else
		self:Print(L["config_enable_off"])
		self.PriorityFrame:Hide()
	end
end

function Watcher:GetGCD()
	return self.db.char.showgcd
end

function Watcher:EnableQuery()
	return self.db.char.enable
end

function Watcher:ActivateDebug()
	self.db.char.debug = not self.db.char.debug
	if (self.db.char.debug) then
		self:Print(L["config_debug_on"])
	else
		self:Print(L["config_debug_off"])
	end
end

function Watcher:ActivateShowCombat()
	self.db.char.showcombat = not self.db.char.showcombat
	self:CreatePriorityFrame()
end

function Watcher:ActivateShowParty()
	self.db.char.showparty = not self.db.char.showparty
	self:CreatePriorityFrame()
end

function Watcher:ActivateShowRaid()
	self.db.char.showraid = not self.db.char.showraid
	self:CreatePriorityFrame()
end

function Watcher:ActivatelnlIcon()
	self.db.char.priority.lnlIcon = not self.db.char.priority.lnlIcon
	if (self.db.char.priority.lnlIcon) then
		for index = 1, 2 do
			self.PriorityFrame.lnl[index].frame:Show()
		end
		self:Print(L["config_lnlIcon_on"])
	else
		for index = 1, 2 do
			self.PriorityFrame.lnl[index].frame:Hide()
		end
		self:Print(L["config_lnlIcon_off"])
	end
end

function Watcher:ShowHideFrame()
	self.db.char.barshow = not self.db.char.barshow
	if self.db.char.barshow then
		self.PriorityFrame:EnableMouse(1)
		self.PriorityFrame:SetBackdropColor(0, 0, 0, 1)
		self.PriorityFrame:Show()

	else
		self.PriorityFrame:EnableMouse(0);
		if self.db.char.priority.show and combat == true then
			self.PriorityFrame:Show()
		else
		self.PriorityFrame:Hide()
		end
	end
end

function Watcher:FinishedMoving(var, frame)
	local point, relativeTo, relativePoint, xOffset, yOffset = frame:GetPoint();
	var.point = point
	var.relativeTo = relativeTo
	var.relativePoint = relativePoint
	var.xOffset = xOffset
	var.yOffset = yOffset
end

function Watcher:GetShowCombat()
	return self.db.char.showcombat
end

function Watcher:GetShowParty()
	return self.db.char.showparty
end

function Watcher:GetShowRaid()
	return self.db.char.showraid
end

function Watcher:BarShowQuery()
	return self.db.char.barshow
end

function Watcher:lnlIconQuery()
	return self.db.char.priority.lnlIcon
end

function Watcher:disableQuery()
	return self.db.char.disablebars
end

function Watcher:bariconsQuery()
	return self.db.char.showicons
end

function Watcher:debugQuery()
	return self.db.char.debug
end

function Watcher:GetScale()
    return self.db.char.scale
end

function Watcher:GetSize()
    return self.db.char.priority.IconSize
end

function Watcher:GetBAlpha()
    return self.db.char.balpha
end

function Watcher:GetAlpha()
    return self.db.char.alpha
end

function Watcher:Getmaxtime()

    return self.db.char.priority.maxtime
end

function Watcher:Setmaxtime(info, newValue)
	Watcher.PriorityFrame.axisbase.text:SetText("")
	self.db.char.priority.maxtime = newValue
	Watcher:CreatePriorityFrame()
	self:Print(L["config_maxtime"]..newValue)
end

function Watcher:Activateaxis()
	self.db.char.showaxis = not self.db.char.showaxis
	--self:CreatePriorityFrame()
	if (self.db.char.showaxis) then
		self.PriorityFrame.axisbase:SetAlpha(1)
		self:Print(L["config_axis_on"])
	else
		self.PriorityFrame.axisbase:SetAlpha(0)
		self:Print(L["config_axis_off"])
	end
end

function Watcher:Getaxis()
	return self.db.char.showaxis
end

function Watcher:GetDirection(info)
	return self.db.char.growdir
end

function Watcher:SetDirection(info, newValue)
	self.PriorityFrame.axisbase.text:SetText()
	self:Print(self.db.char.growdir)
	self.db.char.growdir = self.dir[newValue]	
	self:CreatePriorityFrame()
end

function Watcher:SetScale(info,newValue)
	self.db.char.scale = newValue
	self.PriorityFrame:SetScale(self.db.char.scale)
	self:Print("Scale set to : "..self.db.char.scale)
end

function Watcher:SetSize(info,newValue)
	self.db.char.priority.IconSize = newValue
	self:CreatePriorityFrame()
	self:Print("Icon Size set to : "..self.db.char.priority.IconSize)
end

function Watcher:SetAlpha(info,newValue)
	self.db.char.alpha = newValue
	self.PriorityFrame:SetAlpha(self.db.char.alpha)
	self:Print("Alpha set to : "..self.db.char.alpha)
end

function Watcher:SetBAlpha(info,newValue)
	self.db.char.balpha = newValue
	self.PriorityFrame:SetBackdropColor(0, 0, 0, self.db.char.balpha)
	self:Print("Backdrop Alpha set to : "..self.db.char.balpha)
end

-----------------------------------------
-- Priority Choices
-----------------------------------------

function Watcher:GetFirstPriority(info)
	return self.db.char.priority.option1[2] 
end

function Watcher:SetFirstPriority(info, priorityValue)
	self.db.char.priority.option1[2] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetFirstshowraidboss()
	return self.db.char.priority.onlyboss1[2] 
end

function Watcher:SetFirstshowraidboss()
	self.db.char.priority.onlyboss1[2] = not self.db.char.priority.onlyboss1[2]
	self:Print(self.db.char.priority.onlyboss1[2])
	Watcher:SwitchTalents()
end

function Watcher:GetSecondPriority(info)
	return self.db.char.priority.option1[3] 
end

function Watcher:SetSecondPriority(info, priorityValue)
	self.db.char.priority.option1[3] = priorityValue
	self:CreatePriorityFrame()
end
function Watcher:GetSecondshowraidboss()
	return self.db.char.priority.onlyboss1[3] 
end

function Watcher:SetSecondshowraidboss()
	self.db.char.priority.onlyboss1[3] = not self.db.char.priority.onlyboss1[3]
	self:Print(self.db.char.priority.onlyboss1[3])
	--self:CreatePriorityFrame()
end

function Watcher:GetThirdPriority(info)
	return self.db.char.priority.option1[4] 
end

function Watcher:SetThirdPriority(info, priorityValue)
	self.db.char.priority.option1[4] = priorityValue
	self:CreatePriorityFrame()
end


function Watcher:GetThirdshowraidboss()
	return self.db.char.priority.onlyboss1[4] 
end

function Watcher:SetThirdshowraidboss()
	self.db.char.priority.onlyboss1[4] = not self.db.char.priority.onlyboss1[4]
	--self:CreatePriorityFrame()
end

function Watcher:GetFourthPriority(info)
	return self.db.char.priority.option1[5] 
end

function Watcher:SetFourthPriority(info, priorityValue)
	self.db.char.priority.option1[5] = priorityValue
	self:CreatePriorityFrame()
end


function Watcher:GetFourthshowraidboss()
	return self.db.char.priority.onlyboss1[5] 
end

function Watcher:SetFourthshowraidboss()
	self.db.char.priority.onlyboss1[5] = not self.db.char.priority.onlyboss1[5]
	--self:CreatePriorityFrame()
end

function Watcher:GetFifthPriority(info)
	return self.db.char.priority.option1[6] 
end

function Watcher:SetFifthPriority(info, priorityValue)
	self.db.char.priority.option1[6] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetFifthshowraidboss()
	return self.db.char.priority.onlyboss1[6] 
end

function Watcher:SetFifthshowraidboss()
	self.db.char.priority.onlyboss1[6] = not self.db.char.priority.onlyboss1[6]
	--self:CreatePriorityFrame()
end

function Watcher:GetSixthPriority(info)
	return self.db.char.priority.option1[7] 
end

function Watcher:SetSixthPriority(info, priorityValue)
	self.db.char.priority.option1[7] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetSixthshowraidboss()
	return self.db.char.priority.onlyboss1[7] 
end

function Watcher:SetSixthshowraidboss()
	self.db.char.priority.onlyboss1[7] = not self.db.char.priority.onlyboss1[7]
	--self:CreatePriorityFrame()
end

function Watcher:GetSeventhshowraidboss()
	return self.db.char.priority.onlyboss1[8] 
end

function Watcher:SetSeventhshowraidboss()
	self.db.char.priority.onlyboss1[8] = not self.db.char.priority.onlyboss1[8]
	--self:CreatePriorityFrame()
end

function Watcher:GetSeventhPriority(info)
	return self.db.char.priority.option1[8] 
end

function Watcher:SetSeventhPriority(info, priorityValue)
	self.db.char.priority.option1[8] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetEighthPriority(info)
	return self.db.char.priority.option1[9] 
end

function Watcher:SetEighthPriority(info, priorityValue)
	self.db.char.priority.option1[9] = priorityValue
	self:Print(self.db.char.priority.option1[9])
	self:CreatePriorityFrame()
	end
	
function Watcher:GetEighthshowraidboss()
	return self.db.char.priority.onlyboss1[9] 
end

function Watcher:SetEighthshowraidboss()
	self.db.char.priority.onlyboss1[9] = not self.db.char.priority.onlyboss1[9]
	--self:CreatePriorityFrame()
end


function Watcher:GetFirstPriority2(info)
	return self.db.char.priority.option2[2] 
end

function Watcher:SetFirstPriority2(info, priorityValue)
	self.db.char.priority.option2[2] = priorityValue
	self:CreatePriorityFrame()
end


function Watcher:GetSecondPriority2(info)
	return self.db.char.priority.option2[3] 
end

function Watcher:SetSecondPriority2(info, priorityValue)
	self.db.char.priority.option2[3] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetThirdPriority2(info)
	return self.db.char.priority.option2[4] 
end

function Watcher:SetThirdPriority2(info, priorityValue)
	self.db.char.priority.option2[4] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetFourthPriority2(info)
	return self.db.char.priority.option2[5] 
end

function Watcher:SetFourthPriority2(info, priorityValue)
	self.db.char.priority.option2[5] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetFifthPriority2(info)
	return self.db.char.priority.option2[6] 
end

function Watcher:SetFifthPriority2(info, priorityValue)
	self.db.char.priority.option2[6] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetSixthPriority2(info)
	return self.db.char.priority.option2[7] 
end

function Watcher:SetSixthPriority2(info, priorityValue)
	self.db.char.priority.option2[7] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetSeventhPriority2(info)
	return self.db.char.priority.option2[8] 
end

function Watcher:SetSeventhPriority2(info, priorityValue)
	self.db.char.priority.option2[8] = priorityValue
	self:CreatePriorityFrame()
end

function Watcher:GetEighthPriority2(info)
	return self.db.char.priority.option2[9] 
end

function Watcher:SetEighthPriority2(info, priorityValue)
	self.db.char.priority.option2[9] = priorityValue
	self:Print(self.db.char.priority.option2[9])
	self:CreatePriorityFrame()
	end

function Watcher:GetEighthshowraidboss2()
	return self.db.char.priority.onlyboss2[9] 
end

function Watcher:SetEighthshowraidboss2()
	self.db.char.priority.onlyboss2[9] = not self.db.char.priority.onlyboss2[9]
	--self:CreatePriorityFrame()
end

function Watcher:GetSixthshowraidboss2()
	return self.db.char.priority.onlyboss2[7] 
end

function Watcher:SetSixthshowraidboss2()
	self.db.char.priority.onlyboss2[7] = not self.db.char.priority.onlyboss2[7]
	--self:CreatePriorityFrame()
end

function Watcher:GetSeventhshowraidboss2()
	return self.db.char.priority.onlyboss2[8] 
end

function Watcher:SetSeventhshowraidboss2()
	self.db.char.priority.onlyboss2[8] = not self.db.char.priority.onlyboss2[8]
	--self:CreatePriorityFrame()
end


function Watcher:GetFifthshowraidboss2()
	return self.db.char.priority.onlyboss2[6] 
end

function Watcher:SetFifthshowraidboss2()
	self.db.char.priority.onlyboss2[6] = not self.db.char.priority.onlyboss2[6]
	--self:CreatePriorityFrame()
end

function Watcher:GetFourthshowraidboss2()
	return self.db.char.priority.onlyboss2[5] 
end

function Watcher:SetFourthshowraidboss2()
	self.db.char.priority.onlyboss2[5] = not self.db.char.priority.onlyboss2[5]
	--self:CreatePriorityFrame()
end

function Watcher:GetThirdshowraidboss2()
	return self.db.char.priority.onlyboss2[4] 
end

function Watcher:SetThirdshowraidboss2()
	self.db.char.priority.onlyboss2[4] = not self.db.char.priority.onlyboss2[4]
	--self:CreatePriorityFrame()
end

function Watcher:GetSecondshowraidboss2()
	return self.db.char.priority.onlyboss2[3] 
end

function Watcher:SetSecondshowraidboss2()
	self.db.char.priority.onlyboss2[3] = not self.db.char.priority.onlyboss2[3]
	self:Print(self.db.char.priority.onlyboss2[3])
	--self:CreatePriorityFrame()
end

function Watcher:GetFirstshowraidboss2()
	return self.db.char.priority.onlyboss2[2] 
end

function Watcher:SetFirstshowraidboss2()
	self.db.char.priority.onlyboss2[2] = not self.db.char.priority.onlyboss2[2]
	self:Print(self.db.char.priority.onlyboss2[2])
	Watcher:SwitchTalents()
end	
	
function Watcher:priorityTextQuery()
	return self.db.char.priority.textshow
end

function Watcher:ActivatePriorityText()
	self.db.char.priority.textshow = not self.db.char.priority.textshow
	if self.db.char.priority.textshow then
		self.Priority1.Text:Show()
		self.Priority2.Text:Show()
		self.Priority3.Text:Show()
		self.Priority4.Text:Show()
		self.Priority5.Text:Show()
		self.Priority6.Text:Show()
		self.Priority7.Text:Show()
		self.Priority8.Text:Show()
		self:Print(L["config_prioritytitle_on"])
	else
		self.Priority1.Text:Hide()
		self.Priority2.Text:Hide()
		self.Priority3.Text:Hide()
		self.Priority4.Text:Hide()
		self.Priority5.Text:Hide()
		self.Priority6.Text:Hide()
		self.Priority7.Text:Hide()
		self.Priority8.Text:Hide()
		self:Print(L["config_prioritytitle_off"])
	end
end

function Watcher:OpenConfig()
	  if InterfaceOptionsFrame_OpenToCategory then
	    InterfaceOptionsFrame_OpenToCategory("Watcher");
    else
        InterfaceOptionsFrame_OpenToFrame("Watcher");
    end
end